from typing import Union

import click
import requests
from rich.console import Console

from malwarebazaar import version as ver

try:
    from malwarebazaar import commit

    IS_BINARY = True
except ImportError:
    IS_BINARY = False


@click.command(help="Display version information.")
@click.option("-c", "--check", is_flag=True, help="Check if bazaar is up to date.")
def version(check: bool):
    c = Console(highlight=False)
    github_version = None
    if check:
        github_version = get_latest_release_tag()

    c.print(f"Bazaar v{ver}")
    if IS_BINARY:
        c.print(f"Built from Git commit {commit}.")

    if check:
        if github_version:
            if ver != github_version:
                c.print(f"Your version of Bazaar is out of date. The most recent version is {github_version}.",
                        style="yellow")
            else:
                c.print(f"Your version of Bazaar is up to date.", style="green")
        else:
            c.print("Could not get most recent version from Github.")

    c.print(f"https://github.com/3c7/bazaar/releases/tag/{github_version or ver}")


def get_latest_release_tag() -> Union[str, None]:
    res = requests.get("https://api.github.com/repos/3c7/bazaar/releases")
    if res.status_code != 200:
        return None

    releases = res.json()
    for release in releases:
        if not release["draft"] and not release["prerelease"]:
            return release["tag_name"]
    return None
